==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/kasten/controllers/view/structures/parsers/scriptfileparser.h <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2010, 2011, 2012 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SCRIPTFILEPARSER_H_
#define SCRIPTFILEPARSER_H_

#include "abstractstructureparser.h"

#include <QScriptValue>

class ScriptLogger;
class QScriptEngine;
class DataInformation;

class ScriptFileParser : public AbstractStructureParser
{
    Q_DISABLE_COPY(ScriptFileParser)

public:
    ScriptFileParser(const QString& pluginName, const QString& absolutePath);
    ~ScriptFileParser() override;

    QStringList parseStructureNames() const override;
    QVector<TopLevelDataInformation*> parseStructures() const override;

private:
    QScriptValue loadScriptValue(ScriptLogger* logger, QScriptEngine* engine) const;
};

#endif /* SCRIPTFILEPARSER_H_ */

==> okteta_4.13.0.orig.tar.xz: okteta-4.13.0/kasten/controllers/view/structures/parsers/scriptfileparser.h <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2010, 2011, 2012 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SCRIPTFILEPARSER_H_
#define SCRIPTFILEPARSER_H_

#include "abstractstructureparser.h"

#include <QScriptValue>

class ScriptLogger;
class QScriptEngine;
class DataInformation;

class ScriptFileParser: public AbstractStructureParser
{
    Q_DISABLE_COPY(ScriptFileParser)
public:
    ScriptFileParser(const QString& pluginName, const QString& absolutePath);
    virtual ~ScriptFileParser();

    virtual QStringList parseStructureNames() const;
    virtual QVector<TopLevelDataInformation*> parseStructures() const;

private:
    QScriptValue loadScriptValue(ScriptLogger* logger, QScriptEngine* engine) const;
};

#endif /* SCRIPTFILEPARSER_H_ */
